@@ -82,31 +82,31 @@
 
 namespace Dragon {
 
-MainWindow *MainWindow::s_instance = 0;
+MainWindow *MainWindow::s_instance = nullptr;
 /// @see codeine.h
 QWidget* mainWindow() { return MainWindow::s_instance; }
 
 MainWindow::MainWindow()
     : KXmlGuiWindow()
-    , m_mainView( 0 )
-    , m_audioView( 0 )
+    , m_mainView( nullptr )
+    , m_audioView( nullptr )
     , m_loadView( new LoadView(this) )
     , m_currentWidget( nullptr )
-    , m_leftDock( 0 )
-    , m_positionSlider( 0 )
-    , m_volumeSlider( 0 )
-    , m_timeLabel( 0 )
+    , m_leftDock( nullptr )
+    , m_positionSlider( nullptr )
+    , m_volumeSlider( nullptr )
+    , m_timeLabel( nullptr )
     , m_titleLabel( new QLabel( this ) )
-    , m_playDialog( 0 )
-    , m_menuToggleAction( 0 )
-    , m_stopScreenSaver( 0 )
+    , m_playDialog( nullptr )
+    , m_menuToggleAction( nullptr )
+    , m_stopScreenSaver( nullptr )
     , m_stopSleepCookie( -1 )
     , m_stopScreenPowerMgmtCookie( -1 )
     , m_profileMaxDays(30)
     , m_toolbarIsHidden(false)
     , m_statusbarIsHidden(false)
     , m_menuBarIsHidden(false)
-    , m_FullScreenHandler( 0 )
+    , m_FullScreenHandler( nullptr )
 {
     s_instance = this;
     setMouseTracking( true );
@@ -143,7 +143,7 @@ MainWindow::MainWindow()
 
     {
         KActionCollection* ac = actionCollection();
-        KActionMenu *menuAction = 0;
+        KActionMenu *menuAction = nullptr;
 #define make_menu( name, text ) \
         menuAction = new KActionMenu( text, this ); \
         menuAction->setObjectName( name ); \
@@ -419,8 +419,9 @@ MainWindow::toggleVideoSettings( bool show )
         m_sliders.clear();
         m_sliders << ui.brightnessSlider << ui.contrastSlider << ui.hueSlider <<  ui.saturationSlider;
         updateSliders();
-        foreach( QSlider* slider, m_sliders )
+        for (QSlider* slider : qAsConst(m_sliders)) {
             connect( slider, SIGNAL(valueChanged(int)), engine(), SLOT(settingChanged(int)) );
+        }
 
         connect( ui.defaultsButton, SIGNAL(clicked(bool)), this, SLOT(restoreDefaultVideoSettings()) );
         connect( ui.closeButton, SIGNAL(clicked(bool)), action( "video_settings" ), SLOT(setChecked(bool)) );
@@ -434,8 +435,9 @@ MainWindow::toggleVideoSettings( bool show )
 void
 MainWindow::restoreDefaultVideoSettings()
 {
-    foreach( QSlider* slider, m_sliders )
+    for (QSlider* slider :  qAsConst(m_sliders)) {
         slider->setValue(0);
+    }
 }
 
 void
@@ -514,8 +516,9 @@ void MainWindow::stop()
 void
 MainWindow::updateSliders()
 {
-    foreach( QSlider* slider, m_sliders )
+    for (QSlider* slider : qAsConst(m_sliders)) {
         slider->setValue( engine()->videoSetting( slider->objectName() ) );
+    }
 }
 
 void
@@ -673,7 +676,7 @@ MainWindow::playDisc()
     {
         const QList< Solid::Device > deviceList = Solid::Device::listFromType( Solid::DeviceInterface::OpticalDisc );
 
-        foreach( const Solid::Device &device, deviceList ) {
+        for (const Solid::Device &device : deviceList) {
             const Solid::OpticalDisc* disc = device.as<const Solid::OpticalDisc>();
             if( disc ) {
                 if( disc->availableContent() & ( Solid::OpticalDisc::VideoDvd | Solid::OpticalDisc::VideoCd | Solid::OpticalDisc::SuperVideoCd |  Solid::OpticalDisc::Audio ) )
@@ -701,7 +704,7 @@ void
 MainWindow::openRecentFile(const QUrl &url )
 {
     m_playDialog->deleteLater();
-    m_playDialog = 0;
+    m_playDialog = nullptr;
     this->open( url );
 }
 
@@ -737,7 +740,7 @@ MainWindow::setFullScreen( bool isFullScreen )
         action( "fullscreen" )->setEnabled( videoWindow()->state() == Phonon::PlayingState
                                             || videoWindow()->state() ==  Phonon::PausedState);
         delete m_FullScreenHandler;
-        m_FullScreenHandler = 0;
+        m_FullScreenHandler = nullptr;
     }
 }
 
@@ -764,7 +767,7 @@ MainWindow::aboutToShowMenu()
         const int subId = TheStream::subtitleChannel();
         const QList< QAction* > subs = action("subtitle_channels_menu")->menu()->actions();
         qDebug() << "subtitle #" << subId << " is going to be checked";
-        foreach( QAction* subAction, subs ) {
+        for (QAction* subAction : subs) {
             if( subAction->property( TheStream::CHANNEL_PROPERTY ).toInt() == subId ) {
                 subAction->setChecked( true );
                 break;
@@ -776,7 +779,7 @@ MainWindow::aboutToShowMenu()
         const int audioId = TheStream::audioChannel();
         const QList< QAction* > audios = action("audio_channels_menu")->menu()->actions();
         qDebug() << "audio #" << audioId << " is going to be checked";
-        foreach( QAction* audioAction, audios ) {
+        for (QAction* audioAction : audios) {
             if( audioAction->property( TheStream::CHANNEL_PROPERTY ).toInt() == audioId ) {
                 audioAction->setChecked( true );
                 break;
@@ -861,7 +864,7 @@ MainWindow::releasePowerSave()
 
     //stop disabling screensaver
     delete m_stopScreenSaver; // It is always 0, I have been careful.
-    m_stopScreenSaver = 0;
+    m_stopScreenSaver = nullptr;
 }
 
 QMenu*
@@ -920,8 +923,8 @@ actionCollection()
 QAction*
 action( const char *name )
 {
-    KActionCollection *actionCollection = 0;
-    QAction *action = 0;
+    KActionCollection *actionCollection = nullptr;
+    QAction *action = nullptr;
 
     if( mainWindow() )
         if( ( actionCollection = ((MainWindow*)mainWindow() )->actionCollection() ) )
