@@ -74,7 +74,7 @@ using Phonon::MediaController;
 namespace Dragon {
 
 
-VideoWindow *VideoWindow::s_instance = 0;
+VideoWindow *VideoWindow::s_instance = nullptr;
 
 VideoWindow::VideoWindow( QWidget *parent )
     : QWidget( parent )
@@ -85,7 +85,7 @@ VideoWindow::VideoWindow( QWidget *parent )
     , m_audioLanguages( new QActionGroup( this ) )
     , m_logo( new QLabel( this ) )
     , m_initialOffset( 0 )
-    , m_aDataOutput(0)
+    , m_aDataOutput(nullptr)
 {
     m_isPreview = false;
 
@@ -93,7 +93,7 @@ VideoWindow::VideoWindow( QWidget *parent )
     setObjectName( QLatin1String( "VideoWindow" ) );
 
     QVBoxLayout *box = new QVBoxLayout( this );
-    box->setMargin(0);
+    box->setContentsMargins(0, 0, 0, 0);
     box->setSpacing(0);
     m_vWidget = new VideoWidget( this );
     m_vWidget->hide();
@@ -115,7 +115,7 @@ VideoWindow::VideoWindow( QWidget *parent )
     connect( m_media, SIGNAL(hasVideoChanged(bool)), this, SIGNAL(hasVideoChanged(bool)) );
     connect( m_media, SIGNAL(hasVideoChanged(bool)), m_vWidget, SLOT(setVisible(bool)) ); //hide video widget if no video to show
     connect( m_media, SIGNAL(hasVideoChanged(bool)), m_logo, SLOT(setHidden(bool)) );
-
+    connect( m_media, SIGNAL(finished()), this, SIGNAL(finished()) );
     connect( m_controller, SIGNAL(availableSubtitlesChanged()), this, SLOT(updateChannels()) );
 
     {
@@ -575,7 +575,7 @@ VideoWindow::updateActionGroup( QActionGroup* channelActions
         while( 2 < subActions.size() )
             delete subActions.takeLast();
     }
-    foreach( const ChannelDescription &channel, availableChannels ) {
+    for (const ChannelDescription& channel : availableChannels) {
         QAction* lang = new QAction( channelActions );
         qDebug() << "the text is: \"" << channel.name() << "\" and index " << channel.index();
         lang->setCheckable( true );
