@@ -45,7 +45,7 @@ class MediaPlayer2 : public QDBusAbstractAdaptor
 
 public:
     explicit MediaPlayer2(QObject* parent);
-    ~MediaPlayer2();
+    ~MediaPlayer2() override;
 
     bool CanQuit() const;
     bool CanRaise() const;
@@ -62,11 +62,11 @@ public:
     QStringList SupportedUriSchemes() const;
     QStringList SupportedMimeTypes() const;
 
-public slots:
+public Q_SLOTS:
     void Raise() const;
     void Quit() const;
 
-private slots:
+private Q_SLOTS:
     void emitFullscreenChange(bool fullscreen) const;
 };
 
